@@ -24,12 +24,11 @@
 
 #include <xapian/compactor.h>
 
-#include "safeerrno.h"
-
 #include <algorithm>
 #include <fstream>
 #include <vector>
 
+#include <cerrno>
 #include <cstring>
 #include <ctime>
 #include "safesysstat.h"
@@ -66,11 +65,11 @@
 using namespace std;
 
 class CmpByFirstUsed {
-    const vector<pair<Xapian::docid, Xapian::docid> > & used_ranges;
+    const vector<pair<Xapian::docid, Xapian::docid>>& used_ranges;
 
   public:
     explicit
-    CmpByFirstUsed(const vector<pair<Xapian::docid, Xapian::docid> > & ur)
+    CmpByFirstUsed(const vector<pair<Xapian::docid, Xapian::docid>>& ur)
 	: used_ranges(ur) { }
 
     bool operator()(size_t a, size_t b) const {
@@ -208,8 +207,8 @@ Database::compact_(const string * output_ptr, int fd, unsigned flags,
 	string srcdir;
 	int type = it->get_backend_info(&srcdir);
 	// Check destdir isn't the same as any source directory, unless it
-	// is a stub database.
-	if (!compact_to_stub && srcdir == destdir)
+	// is a stub database or we're compacting to an fd.
+	if (!compact_to_stub && !destdir.empty() && srcdir == destdir)
 	    throw Xapian::InvalidArgumentError("destination may not be the same as any source database, unless it is a stub database");
 	switch (type) {
 	    case BACKEND_CHERT:
@@ -299,7 +298,7 @@ Database::compact_(const string * output_ptr, int fd, unsigned flags,
 	// set all the offsets to 0.
 	vector<Xapian::Database::Internal *> internals_;
 	internals_.reserve(internal.size());
-	vector<pair<Xapian::docid, Xapian::docid> > used_ranges_;
+	vector<pair<Xapian::docid, Xapian::docid>> used_ranges_;
 	used_ranges_.reserve(internal.size());
 
 	Xapian::docid last_start = 0, last_end = 0;
@@ -368,16 +367,11 @@ Database::compact_(const string * output_ptr, int fd, unsigned flags,
 	    // Check why mkdir failed.  It's ok if the directory already
 	    // exists, but we also get EEXIST if there's an existing file with
 	    // that name.
-	    if (errno == EEXIST) {
-		if (dir_exists(destdir))
-		    errno = 0;
-		else
-		    errno = EEXIST; // dir_exists() might have changed it
-	    }
-	    if (errno) {
+	    int mkdir_errno = errno;
+	    if (mkdir_errno != EEXIST || !dir_exists(destdir)) {
 		string msg = destdir;
 		msg += ": cannot create directory";
-		throw Xapian::DatabaseError(msg, errno);
+		throw Xapian::DatabaseError(msg, mkdir_errno);
 	    }
 	}
     }
@@ -427,11 +421,7 @@ Database::compact_(const string * output_ptr, int fd, unsigned flags,
 	new_stub_file += "/new_stub.tmp";
 	{
 	    ofstream new_stub(new_stub_file.c_str());
-#ifndef __WIN32__
-	    size_t slash = destdir.find_last_of('/');
-#else
-	    size_t slash = destdir.find_last_of("/\\");
-#endif
+	    size_t slash = destdir.find_last_of(DIR_SEPS);
 	    new_stub << "auto " << destdir.substr(slash + 1) << '\n';
 	}
 	if (!io_tmp_rename(new_stub_file, stub_file)) {
