@@ -2,7 +2,7 @@
  * @brief A posting source which returns decreasing weights from a value.
  */
 /* Copyright (C) 2009 Lemur Consulting Ltd
- * Copyright (C) 2015 Olly Betts
+ * Copyright (C) 2011,2012,2015,2016 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #include "xapian/postingsource.h"
 #include "xapian/error.h"
 #include "net/length.h"
-#include "serialise.h"
 #include "serialise-double.h"
 #include <cmath>
 
@@ -40,14 +39,14 @@ DecreasingValueWeightPostingSource::DecreasingValueWeightPostingSource(
 {
 }
 
-Xapian::weight
+double
 DecreasingValueWeightPostingSource::get_weight() const {
     return curr_weight;
 }
 
 Xapian::DecreasingValueWeightPostingSource *
 DecreasingValueWeightPostingSource::clone() const {
-    return new DecreasingValueWeightPostingSource(slot, range_start,
+    return new DecreasingValueWeightPostingSource(get_slot(), range_start,
 						  range_end);
 }
 
@@ -59,7 +58,7 @@ DecreasingValueWeightPostingSource::name() const {
 std::string
 DecreasingValueWeightPostingSource::serialise() const {
     std::string result;
-    result += encode_length(slot);
+    result += encode_length(get_slot());
     result += encode_length(range_start);
     result += encode_length(range_end);
     return result;
@@ -84,30 +83,30 @@ DecreasingValueWeightPostingSource::unserialise(const std::string &s) const {
 void
 DecreasingValueWeightPostingSource::init(const Xapian::Database & db_) {
     Xapian::ValueWeightPostingSource::init(db_);
-    if (range_end == 0 || db.get_doccount() <= range_end)
+    if (range_end == 0 || get_database().get_doccount() <= range_end)
 	items_at_end = false;
     else
 	items_at_end = true;
 }
 
 void
-DecreasingValueWeightPostingSource::skip_if_in_range(Xapian::weight min_wt)
+DecreasingValueWeightPostingSource::skip_if_in_range(double min_wt)
 {
-    if (value_it == db.valuestream_end(slot)) return;
+    if (ValueWeightPostingSource::at_end()) return;
     curr_weight = Xapian::ValueWeightPostingSource::get_weight();
     Xapian::docid docid = Xapian::ValueWeightPostingSource::get_docid();
     if (docid >= range_start && (range_end == 0 || docid <= range_end)) {
 	if (items_at_end) {
 	    if (curr_weight < min_wt) {
 		// skip to end of range.
-		value_it.skip_to(range_end + 1);
-		if (value_it != db.valuestream_end(slot))
+		ValueWeightPostingSource::skip_to(range_end + 1, min_wt);
+		if (!ValueWeightPostingSource::at_end())
 		    curr_weight = Xapian::ValueWeightPostingSource::get_weight();
 	    }
 	} else {
 	    if (curr_weight < min_wt) {
 		// terminate early.
-		value_it = db.valuestream_end(slot);
+		done();
 	    } else {
 		// Update max_weight.
 		set_maxweight(curr_weight);
@@ -117,10 +116,9 @@ DecreasingValueWeightPostingSource::skip_if_in_range(Xapian::weight min_wt)
 }
 
 void
-DecreasingValueWeightPostingSource::next(Xapian::weight min_wt) {
+DecreasingValueWeightPostingSource::next(double min_wt) {
     if (get_maxweight() < min_wt) {
-	value_it = db.valuestream_end(slot);
-	started = true;
+	done();
 	return;
     }
     Xapian::ValueWeightPostingSource::next(min_wt);
@@ -129,10 +127,9 @@ DecreasingValueWeightPostingSource::next(Xapian::weight min_wt) {
 
 void
 DecreasingValueWeightPostingSource::skip_to(Xapian::docid min_docid,
-					    Xapian::weight min_wt) {
+					    double min_wt) {
     if (get_maxweight() < min_wt) {
-	value_it = db.valuestream_end(slot);
-	started = true;
+	done();
 	return;
     }
     Xapian::ValueWeightPostingSource::skip_to(min_docid, min_wt);
@@ -141,10 +138,9 @@ DecreasingValueWeightPostingSource::skip_to(Xapian::docid min_docid,
 
 bool
 DecreasingValueWeightPostingSource::check(Xapian::docid min_docid,
-					  Xapian::weight min_wt) {
+					  double min_wt) {
     if (get_maxweight() < min_wt) {
-	value_it = db.valuestream_end(slot);
-	started = true;
+	done();
 	return true;
     }
     bool valid = Xapian::ValueWeightPostingSource::check(min_docid, min_wt);
