@@ -1,7 +1,7 @@
 /** @file error.cc
  *  @brief Xapian::Error base class.
  */
-/* Copyright (C) 2007,2008,2014 Olly Betts
+/* Copyright (C) 2007,2008,2011,2013,2014,2015 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,25 +22,26 @@
 
 #include <xapian/error.h>
 
-#include "safeerrno.h"
 #ifdef __WIN32__
 # include "safewindows.h"
 #else
 # include "safenetdb.h"
 #endif
 
+#include <cerrno>
 #include <cstdlib> // For abs().
 #include <cstring> // For memcmp().
 
 #include "errno_to_string.h"
 #include "str.h"
+#include "unicode/description_append.h"
 
 using namespace std;
 
 Xapian::Error::Error(const std::string &msg_, const std::string &context_,
 		     const char * type_, const char * error_string_)
-    : msg(msg_), context(context_), type(type_), my_errno(0),
-      error_string(), already_handled(false)
+    : msg(msg_), context(context_), error_string(), type(type_),
+      my_errno(0), already_handled(false)
 {
     if (error_string_) error_string.assign(error_string_);
 }
@@ -75,34 +76,13 @@ Xapian::Error::get_error_string() const
 	if (my_errno > 0) {
 	    errno_to_string(my_errno, error_string);
 	} else {
-# ifndef HAVE_HSTRERROR
-	    const char * s = NULL;
-	    switch (-my_errno) {
-		case HOST_NOT_FOUND:
-		    s = "Unknown host";
-		    break;
-		case NO_ADDRESS:
-#  if NO_ADDRESS != NO_DATA
-		case NO_DATA:
-#  endif
-		    s = "No address associated with name";
-		    break;
-		case NO_RECOVERY:
-		    s = "Unknown server error";
-		    break;
-		case TRY_AGAIN:
-		    s = "Host name lookup failure";
-		    break;
-	    }
-	    if (s) {
-		error_string.assign(s);
-	    } else {
-		error_string = "Unknown Error ";
-		error_string += str(-my_errno);
-	    }
-# else
-	    error_string.assign(hstrerror(-my_errno));
-# endif
+	    // POSIX says only that EAI_* constants are "non-zero" - they're
+	    // negative on Linux, but we allow for them being positive.  We
+	    // check they all that the same sign in net/remoteconnection.h.
+	    if (EAI_FAIL > 0)
+		error_string.assign(gai_strerror(-my_errno));
+	    else
+		error_string.assign(gai_strerror(my_errno));
 	}
 #endif
     }
@@ -112,18 +92,18 @@ Xapian::Error::get_error_string() const
 string
 Xapian::Error::get_description() const
 {
-    string desc(type);
+    string desc(get_type());
     desc += ": ";
     desc += msg;
     if (!context.empty()) {
 	desc += " (context: ";
-	desc += context;
+	description_append(desc, context);
 	desc += ')';
     }
     const char *e = get_error_string();
     if (e) {
 	desc += " (";
-	desc += e;
+	description_append(desc, e);
 	desc += ')';
     }
     return desc;
