@@ -63,10 +63,6 @@
 
 using namespace std;
 
-template<class CLASS> struct delete_ptr {
-    void operator()(CLASS *p) const { delete p; }
-};
-
 using Xapian::Internal::AndContext;
 using Xapian::Internal::OrContext;
 using Xapian::Internal::XorContext;
@@ -325,6 +321,10 @@ class AndContext : public Context {
 
     list<PosFilter> pos_filters;
 
+    AutoPtr<OrContext> not_ctx;
+
+    AutoPtr<OrContext> maybe_ctx;
+
   public:
     AndContext(QueryOptimiser* qopt_, size_t reserve)
 	: Context(qopt_, reserve) { }
@@ -333,6 +333,20 @@ class AndContext : public Context {
 			size_t n_subqs,
 			Xapian::termcount window);
 
+    OrContext& get_not_ctx(size_t reserve) {
+	if (!not_ctx) {
+	    not_ctx.reset(new OrContext(qopt, reserve));
+	}
+	return *not_ctx;
+    }
+
+    OrContext& get_maybe_ctx(size_t reserve) {
+	if (!maybe_ctx) {
+	    maybe_ctx.reset(new OrContext(qopt, reserve));
+	}
+	return *maybe_ctx;
+    }
+
     PostList * postlist();
 };
 
@@ -378,8 +392,17 @@ AndContext::postlist()
 	return new EmptyPostList;
     }
 
+    auto matcher = qopt->matcher;
+    auto db_size = qopt->db_size;
+
     AutoPtr<PostList> pl(new MultiAndPostList(pls.begin(), pls.end(),
-					      qopt->matcher, qopt->db_size));
+					      matcher, db_size));
+
+    if (not_ctx) {
+	PostList* rhs = not_ctx->postlist();
+	pl.reset(new AndNotPostList(pl.release(), rhs, matcher, db_size));
+	not_ctx.reset();
+    }
 
     // Sort the positional filters to try to apply them in an efficient order.
     // FIXME: We need to figure out what that is!  Try applying lowest cf/tf
@@ -394,6 +417,13 @@ AndContext::postlist()
 
     // Empty pls so our destructor doesn't delete them all!
     pls.clear();
+
+    if (maybe_ctx) {
+	PostList* rhs = maybe_ctx->postlist();
+	pl.reset(new AndMaybePostList(pl.release(), rhs, matcher, db_size));
+	maybe_ctx.reset();
+    }
+
     return pl.release();
 }
 
@@ -1650,7 +1680,6 @@ PostingIterator::Internal *
 QueryAndNot::postlist(QueryOptimiser * qopt, double factor) const
 {
     LOGCALL(QUERY, PostingIterator::Internal *, "QueryAndNot::postlist", qopt | factor);
-    // FIXME: Combine and-like side with and-like stuff above.
     AutoPtr<PostList> l(subqueries[0].internal->postlist(qopt, factor));
     OrContext ctx(qopt, subqueries.size() - 1);
     do_or_like(ctx, qopt, 0.0, 0, 1);
@@ -1659,6 +1688,15 @@ QueryAndNot::postlist(QueryOptimiser * qopt, double factor) const
 			      qopt->matcher, qopt->db_size));
 }
 
+void
+QueryAndNot::postlist_sub_and_like(AndContext& ctx,
+				   QueryOptimiser* qopt,
+				   double factor) const
+{
+    subqueries[0].internal->postlist_sub_and_like(ctx, qopt, factor);
+    do_or_like(ctx.get_not_ctx(subqueries.size() - 1), qopt, 0.0, 0, 1);
+}
+
 PostingIterator::Internal *
 QueryXor::postlist(QueryOptimiser * qopt, double factor) const
 {
@@ -1696,6 +1734,15 @@ QueryAndMaybe::postlist(QueryOptimiser * qopt, double factor) const
 				qopt->matcher, qopt->db_size));
 }
 
+void
+QueryAndMaybe::postlist_sub_and_like(AndContext& ctx,
+				     QueryOptimiser* qopt,
+				     double factor) const
+{
+    subqueries[0].internal->postlist_sub_and_like(ctx, qopt, factor);
+    do_or_like(ctx.get_maybe_ctx(subqueries.size() - 1), qopt, factor, 0, 1);
+}
+
 PostingIterator::Internal *
 QueryFilter::postlist(QueryOptimiser * qopt, double factor) const
 {
