@@ -30,10 +30,9 @@
 #include <algorithm>
 #include <queue>
 
+#include <cerrno>
 #include <cstdio>
 
-#include "safeerrno.h"
-
 #include "backends/flint_lock.h"
 #include "glass_database.h"
 #include "glass_defs.h"
@@ -338,7 +337,7 @@ merge_postlists(Xapian::Compactor * compactor,
     }
 
     Xapian::termcount tf = 0, cf = 0; // Initialise to avoid warnings.
-    vector<pair<Xapian::docid, string> > tags;
+    vector<pair<Xapian::docid, string>> tags;
     while (true) {
 	PostlistCursor * cur = NULL;
 	if (!pq.empty()) {
@@ -365,8 +364,7 @@ merge_postlists(Xapian::Compactor * compactor,
 			throw Xapian::DatabaseCorruptError("Bad postlist chunk key");
 		}
 
-		vector<pair<Xapian::docid, string> >::const_iterator i;
-		i = tags.begin();
+		auto i = tags.begin();
 		while (++i != tags.end()) {
 		    tag = i->second;
 		    tag[0] = (i + 1 == tags.end()) ? '1' : '0';
@@ -570,7 +568,7 @@ merge_synonyms(GlassTable * out,
 	    pqtag.pop();
 	    if (**it != lastword) {
 		lastword = **it;
-		tag += byte(lastword.size() ^ MAGIC_XOR_VALUE);
+		tag += uint8_t(lastword.size() ^ MAGIC_XOR_VALUE);
 		tag += lastword;
 	    }
 	    ++*it;
