@@ -2080,7 +2080,7 @@ GlassTable::next_for_sequential(Glass::Cursor * C_, int /*dummy*/) const
     int c = C_[0].c;
     AssertRel(c,<,DIR_END(p));
     c += D2;
-    Assert((unsigned)c < block_size);
+    Assert(unsigned(c) < block_size);
     if (c == DIR_END(p)) {
 	uint4 n = C_[0].get_n();
 	while (true) {
@@ -2136,7 +2136,7 @@ GlassTable::prev_default(Glass::Cursor * C_, int j) const
     int c = C_[j].c;
     AssertRel(DIR_START,<=,c);
     AssertRel(c,<,DIR_END(p));
-    AssertRel((unsigned)DIR_END(p),<=,block_size);
+    AssertRel(unsigned(DIR_END(p)),<=,block_size);
     if (c == DIR_START) {
 	if (j == level) RETURN(false);
 	if (!prev_default(C_, j + 1)) RETURN(false);
@@ -2159,7 +2159,7 @@ GlassTable::next_default(Glass::Cursor * C_, int j) const
     const uint8_t * p = C_[j].get_p();
     int c = C_[j].c;
     AssertRel(c,<,DIR_END(p));
-    AssertRel((unsigned)DIR_END(p),<=,block_size);
+    AssertRel(unsigned(DIR_END(p)),<=,block_size);
     c += D2;
     if (j > 0) {
 	AssertRel(DIR_START,<,c);
