@@ -1,7 +1,7 @@
 /* multi_postlist.cc: interface to multiple database access
  *
  * Copyright 1999,2000,2001 BrightStation PLC
- * Copyright 2002,2003,2004,2005,2007,2008,2009 Olly Betts
+ * Copyright 2002,2003,2004,2005,2007,2008,2009,2011 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,7 +25,6 @@
 
 #include "debuglog.h"
 #include "omassert.h"
-#include "utils.h"
 
 #ifdef XAPIAN_ASSERTIONS_PARANOID
 #include "xapian/database.h"
@@ -71,13 +70,13 @@ MultiPostList::get_termfreq_est() const
     return MultiPostList::get_termfreq_min();
 }
 
-Xapian::weight
+double
 MultiPostList::get_maxweight() const
 {
     return MultiPostList::get_weight();
 }
 
-Xapian::weight
+double
 MultiPostList::get_weight() const
 {
     // Should never get called.
@@ -85,7 +84,7 @@ MultiPostList::get_weight() const
     return 0;
 }
 
-Xapian::weight
+double
 MultiPostList::recalc_maxweight()
 {
     return MultiPostList::get_weight();
@@ -111,6 +110,17 @@ MultiPostList::get_doclength() const
     RETURN(result);
 }
 
+Xapian::termcount
+MultiPostList::get_unique_terms() const
+{
+    LOGCALL(DB, Xapian::termcount, "MultiPostList::get_unique_terms", NO_ARGS);
+    Assert(!at_end());
+    Assert(currdoc != 0);
+    Xapian::termcount result = postlists[(currdoc - 1) % multiplier]->get_unique_terms();
+    AssertEqParanoid(result, this_db.get_unique_terms(get_docid()));
+    RETURN(result);
+}
+
 Xapian::termcount
 MultiPostList::get_wdf() const
 {
@@ -124,7 +134,7 @@ MultiPostList::open_position_list() const
 }
 
 PostList *
-MultiPostList::next(Xapian::weight w_min)
+MultiPostList::next(double w_min)
 {
     LOGCALL(DB, PostList *, "MultiPostList::next", w_min);
     Assert(!at_end());
@@ -161,7 +171,7 @@ MultiPostList::next(Xapian::weight w_min)
 }
 
 PostList *
-MultiPostList::skip_to(Xapian::docid did, Xapian::weight w_min)
+MultiPostList::skip_to(Xapian::docid did, double w_min)
 {
     LOGCALL(DB, PostList *, "MultiPostList::skip_to", did | w_min);
     Assert(!at_end());
