@@ -2,7 +2,7 @@
  *  @brief Postlists for remote databases
  */
 /* Copyright (C) 2007 Lemur Consulting Ltd
- * Copyright (C) 2007,2008,2009,2015 Olly Betts
+ * Copyright (C) 2007,2008,2009,2011,2012,2013,2015 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,9 +23,8 @@
 #include <config.h>
 
 #include "net_postlist.h"
-
 #include "net/length.h"
-#include "serialise.h"
+#include "unicode/description_append.h"
 
 using namespace std;
 
@@ -47,6 +46,12 @@ NetworkPostList::get_doclength() const
     return db->get_doclength(lastdocid);
 }
 
+Xapian::termcount
+NetworkPostList::get_unique_terms() const
+{
+    return db->get_unique_terms(lastdocid);
+}
+
 Xapian::termcount
 NetworkPostList::get_wdf() const
 {
@@ -67,7 +72,7 @@ NetworkPostList::open_position_list() const
 }
 
 PostList *
-NetworkPostList::next(Xapian::weight)
+NetworkPostList::next(double)
 {
     if (!started) {
 	started = true;
@@ -90,7 +95,7 @@ NetworkPostList::next(Xapian::weight)
 }
 
 PostList *
-NetworkPostList::skip_to(Xapian::docid did, Xapian::weight min_weight)
+NetworkPostList::skip_to(Xapian::docid did, double min_weight)
 {
     if (!started)
 	next(min_weight);
@@ -109,7 +114,7 @@ string
 NetworkPostList::get_description() const
 {
     string desc = "NetworkPostList(";
-    desc += term;
+    description_append(desc, term);
     desc += ')';
     return desc;
 }
