@@ -52,6 +52,21 @@
 using namespace std;
 using Xapian::Internal::intrusive_ptr;
 
+/// Return true if further replies should be expected.
+static inline bool
+is_intermediate_reply(int msg_code, int reply_code)
+{
+    return reply_code == REPLY_ALLTERMS ||
+	   reply_code == REPLY_DOCDATA ||
+	   reply_code == REPLY_VALUE ||
+	   reply_code == REPLY_TERMLIST ||
+	   reply_code == REPLY_POSITIONLIST ||
+	   reply_code == REPLY_POSTLISTSTART ||
+	   reply_code == REPLY_POSTLISTITEM ||
+	   reply_code == REPLY_METADATAKEYLIST ||
+	   (msg_code == MSG_TERMLIST && reply_code == REPLY_DOCLENGTH);
+}
+
 XAPIAN_NORETURN(static void throw_handshake_failed(const string & context));
 static void
 throw_handshake_failed(const string & context)
@@ -557,6 +572,9 @@ RemoteDatabase::get_message(string &result,
 {
     double end_time = RealTime::end_time(timeout);
     int type = link.get_message(result, end_time);
+    if (pending_reply >= 0 && !is_intermediate_reply(pending_reply, type)) {
+	pending_reply = -1;
+    }
     if (type < 0)
 	throw_connection_closed_unexpectedly();
     if (rare(type) >= REPLY_MAX) {
@@ -588,7 +606,23 @@ void
 RemoteDatabase::send_message(message_type type, const string &message) const
 {
     double end_time = RealTime::end_time(timeout);
+    while (pending_reply >= 0) {
+	string dummy;
+	int reply_code = link.get_message(dummy, end_time);
+	if (reply_code < 0)
+	    throw_connection_closed_unexpectedly();
+	if (!is_intermediate_reply(pending_reply, reply_code)) {
+	    pending_reply = -1;
+	}
+    }
     link.send_message(static_cast<unsigned char>(type), message, end_time);
+    if (type == MSG_REMOVESPELLING) {
+	// MSG_REMOVESPELLING is the only message we send which doesn't expect
+	// a reply (except MSG_SHUTDOWN which causes us to exit anyway).
+	pending_reply = -1;
+    } else {
+	pending_reply = int(type);
+    }
 }
 
 void
