@@ -1,7 +1,7 @@
 /** @file slowvaluelist.h
  * @brief Slow implementation for backends which don't streamed values.
  */
-/* Copyright (C) 2007,2008,2014 Olly Betts
+/* Copyright (C) 2007,2008,2011,2014 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,7 +27,7 @@
 
 /** Slow implementation for backends which don't streamed values.
  *
- *  Used by flint, inmemory, and remote backends.
+ *  Used by inmemory and remote backends.
  */
 class SlowValueList : public ValueList {
     /// Don't allow assignment.
@@ -37,7 +37,7 @@ class SlowValueList : public ValueList {
     SlowValueList(const SlowValueList &);
 
     /// The subdatabase.
-    Xapian::Internal::RefCntPtr<const Xapian::Database::Internal> db;
+    Xapian::Internal::intrusive_ptr<const Xapian::Database::Internal> db;
 
     /// The last docid in the database, or 0 if we're at_end.
     Xapian::docid last_docid;
