@@ -22,6 +22,10 @@
 #ifndef XAPIAN_INCLUDED_IO_UTILS_H
 #define XAPIAN_INCLUDED_IO_UTILS_H
 
+#ifndef PACKAGE
+# error config.h must be included first in each C++ source file
+#endif
+
 #include <sys/types.h>
 #include "safefcntl.h"
 #include "safeunistd.h"
