@@ -3,7 +3,7 @@
  */
 /* Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2011,2012,2013,2014,2015,2016 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2011,2012,2013,2014,2015,2016,2017,2019 Olly Betts
  * Copyright 2006,2008 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
@@ -31,6 +31,9 @@
 
 #include <iosfwd>
 #include <string>
+#ifdef XAPIAN_MOVE_SEMANTICS
+# include <utility>
+#endif
 #include <vector>
 
 #include <xapian/attributes.h>
@@ -86,6 +89,11 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 */
 	void add_database(const Database & database);
 
+	/** Return number of shards in this Database object. */
+	size_t size() const {
+	    return internal.size();
+	}
+
 	/** Create a Database with no databases in.
 	 */
 	Database();
@@ -136,6 +144,14 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 */
 	void operator=(const Database &other);
 
+#ifdef XAPIAN_MOVE_SEMANTICS
+	/// Move constructor.
+	Database(Database&& o);
+
+	/// Move assignment operator.
+	Database& operator=(Database&& o);
+#endif
+
 	/** Re-open the database.
 	 *
 	 *  This re-opens the database(s) to the latest available version(s).
@@ -259,6 +275,12 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	/// Get the average length of the documents in the database.
 	Xapian::doclength get_avlength() const;
 
+	/** Get the total length of all the documents in the database.
+	 *
+	 *  Added in Xapian 1.4.5.
+	 */
+	Xapian::totallength get_total_length() const;
+
 	/// Get the number of documents in the database indexed by a given term.
 	Xapian::doccount get_termfreq(const std::string & tname) const;
 
@@ -289,9 +311,6 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 *  stored in the slot.
 	 *
 	 *  @param slot The value slot to examine.
-	 *
-	 *  @exception UnimplementedError The frequency of the value isn't
-	 *  available for this database type.
 	 */
 	Xapian::doccount get_value_freq(Xapian::valueno slot) const;
 
@@ -300,9 +319,6 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 *  If there are no values stored in the given value slot, this will
 	 *  return an empty string.
 	 *
-	 *  If the lower bound isn't available for the given database type,
-	 *  this will return the lowest possible bound - the empty string.
-	 *
 	 *  @param slot The value slot to examine.
 	 */
 	std::string get_value_lower_bound(Xapian::valueno slot) const;
@@ -313,9 +329,6 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 *  return an empty string.
 	 *
 	 *  @param slot The value slot to examine.
-	 *
-	 *  @exception UnimplementedError The upper bound of the values isn't
-	 *  available for this database type.
 	 */
 	std::string get_value_upper_bound(Xapian::valueno slot) const;
 
@@ -438,7 +451,7 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	/** Get the user-specified metadata associated with a given key.
 	 *
 	 *  User-specified metadata allows you to store arbitrary information
-	 *  in the form of (key,tag) pairs.  See @a
+	 *  in the form of (key, value) pairs.  See @a
 	 *  WritableDatabase::set_metadata() for more information.
 	 *
 	 *  When invoked on a Xapian::Database object representing multiple
@@ -846,6 +859,17 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 */
 	void operator=(const WritableDatabase &other);
 
+#ifdef XAPIAN_MOVE_SEMANTICS
+	/// Move constructor.
+	WritableDatabase(WritableDatabase&& o) : Database(std::move(o)) {}
+
+	/// Move assignment operator.
+	WritableDatabase& operator=(WritableDatabase&& o) {
+	    Database::operator=(std::move(o));
+	    return *this;
+	}
+#endif
+
 	/** Commit any pending modifications made to the database.
 	 *
 	 *  For efficiency reasons, when performing multiple updates to a
@@ -1185,11 +1209,11 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 *  existing item of metadata, just set its value to the empty string.
 	 *
 	 *  User-specified metadata allows you to store arbitrary information
-	 *  in the form of (key,tag) pairs.
+	 *  in the form of (key, value) pairs.
 	 *
 	 *  There's no hard limit on the number of metadata items, or the size
 	 *  of the metadata values.  Metadata keys have a limited length, which
-	 *  depends on the backend.  We recommend limiting them to 200 bytes.
+	 *  depend on the backend.  We recommend limiting them to 200 bytes.
 	 *  Empty keys are not valid, and specifying one will cause an
 	 *  exception.
 	 *
@@ -1204,9 +1228,9 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 *  associated with terms, documents, or postings by encoding the
 	 *  termname and/or document id into the metadata key.
 	 *
-	 *  @param key   The key of the metadata item to set.
+	 *  @param key       The key of the metadata item to set.
 	 *
-	 *  @param value The value of the metadata item to set.
+	 *  @param metadata  The value of the metadata item to set.
 	 *
 	 *  @exception Xapian::DatabaseError will be thrown if a problem occurs
 	 *             while writing to the database.
@@ -1221,7 +1245,7 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 *             database backend in use doesn't support user-specified
 	 *             metadata.
 	 */
-	void set_metadata(const std::string & key, const std::string & value);
+	void set_metadata(const std::string & key, const std::string & metadata);
 
 	/// Return a string describing this object.
 	std::string get_description() const;
