@@ -55,6 +55,24 @@ class XAPIAN_VISIBILITY_DEFAULT ValueIterator {
     /// Assignment.
     ValueIterator & operator=(const ValueIterator & o);
 
+#ifdef XAPIAN_MOVE_SEMANTICS
+    /// Move constructor.
+    ValueIterator(ValueIterator && o)
+	: internal(o.internal) {
+	o.internal = nullptr;
+    }
+
+    /// Move assignment operator.
+    ValueIterator & operator=(ValueIterator && o) {
+	if (this != &o) {
+	    if (internal) decref();
+	    internal = o.internal;
+	    o.internal = nullptr;
+	}
+	return *this;
+    }
+#endif
+
     /** Default constructor.
      *
      *  Creates an uninitialised iterator, which can't be used before being
@@ -147,7 +165,7 @@ class XAPIAN_VISIBILITY_DEFAULT ValueIterator {
     // macro.  Apple have deprecated check() in favour of __Check() and
     // plan to remove check() in a "future release", but for now prevent
     // expansion of check by adding parentheses in the method prototype:
-    // http://www.opensource.apple.com/source/CarbonHeaders/CarbonHeaders-18.1/AssertMacros.h
+    // https://www.opensource.apple.com/source/CarbonHeaders/CarbonHeaders-18.1/AssertMacros.h
     //
     // We do this conditionally, as these parentheses trip up SWIG's
     // parser:
