@@ -97,7 +97,11 @@ MaxPostList::get_termfreq_est_using_stats(
 	rtf_scale = 1.0 / stats.rset_size;
     }
     double Pr_est = freqs.reltermfreq * rtf_scale;
-    double cf_scale = 1.0 / stats.total_term_count;
+    // If total_length is 0, cf must always be 0 so cf_scale is irrelevant.
+    double cf_scale = 0.0;
+    if (usual(stats.total_length != 0)) {
+	cf_scale = 1.0 / stats.total_length;
+    }
     double Pc_est = freqs.collfreq * cf_scale;
 
     for (size_t i = 1; i < n_kids; ++i) {
@@ -115,7 +119,7 @@ MaxPostList::get_termfreq_est_using_stats(
     }
     return TermFreqs(Xapian::doccount(P_est * stats.collection_size + 0.5),
 		     Xapian::doccount(Pr_est * stats.rset_size + 0.5),
-		     Xapian::termcount(Pc_est * stats.total_term_count + 0.5));
+		     Xapian::termcount(Pc_est * stats.total_length + 0.5));
 }
 
 double
