@@ -1,7 +1,7 @@
 /** @file msetpostlist.cc
  *  @brief PostList returning entries from an MSet
  */
-/* Copyright (C) 2006,2007,2009,2010,2015 Olly Betts
+/* Copyright (C) 2006,2007,2009,2010,2011,2015 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,10 @@
 #include "debuglog.h"
 #include "omassert.h"
 
+#include "xapian/error.h"
+
+using namespace std;
+
 Xapian::doccount
 MSetPostList::get_termfreq_min() const
 {
@@ -46,10 +50,10 @@ MSetPostList::get_termfreq_max() const
     RETURN(mset_internal->matches_upper_bound);
 }
 
-Xapian::weight
+double
 MSetPostList::get_maxweight() const
 {
-    LOGCALL(MATCH, Xapian::weight, "MSetPostList::get_maxweight", NO_ARGS);
+    LOGCALL(MATCH, double, "MSetPostList::get_maxweight", NO_ARGS);
     // If we've not started, return max_possible from our MSet so that this
     // value gets used to set max_possible in the combined MSet.
     if (cursor == -1) RETURN(mset_internal->max_possible);
@@ -74,10 +78,10 @@ MSetPostList::get_docid() const
     RETURN(mset_internal->items[cursor].did);
 }
 
-Xapian::weight
+double
 MSetPostList::get_weight() const
 {
-    LOGCALL(MATCH, Xapian::weight, "MSetPostList::get_weight", NO_ARGS);
+    LOGCALL(MATCH, double, "MSetPostList::get_weight", NO_ARGS);
     Assert(cursor != -1);
     RETURN(mset_internal->items[cursor].wt);
 }
@@ -93,7 +97,7 @@ MSetPostList::get_sort_key() const
 const string *
 MSetPostList::get_collapse_key() const
 {
-    LOGCALL(MATCH, string *, "MSetPostList::get_collapse_key", NO_ARGS);
+    LOGCALL(MATCH, const string *, "MSetPostList::get_collapse_key", NO_ARGS);
     Assert(cursor != -1);
     RETURN(&mset_internal->items[cursor].collapse_key);
 }
@@ -104,15 +108,21 @@ MSetPostList::get_doclength() const
     throw Xapian::UnimplementedError("MSetPostList::get_doclength() unimplemented");
 }
 
-Xapian::weight
+Xapian::termcount
+MSetPostList::get_unique_terms() const
+{
+    throw Xapian::UnimplementedError("MSetPostList::get_unique_terms() unimplemented");
+}
+
+double
 MSetPostList::recalc_maxweight()
 {
-    LOGCALL(MATCH, Xapian::weight, "MSetPostList::recalc_maxweight", NO_ARGS);
+    LOGCALL(MATCH, double, "MSetPostList::recalc_maxweight", NO_ARGS);
     RETURN(MSetPostList::get_maxweight());
 }
 
 PostList *
-MSetPostList::next(Xapian::weight w_min)
+MSetPostList::next(double w_min)
 {
     LOGCALL(MATCH, PostList *, "MSetPostList::next", w_min);
     Assert(cursor == -1 || !at_end());
@@ -132,7 +142,7 @@ MSetPostList::next(Xapian::weight w_min)
 }
 
 PostList *
-MSetPostList::skip_to(Xapian::docid, Xapian::weight)
+MSetPostList::skip_to(Xapian::docid, double)
 {
     // The usual semantics of skip_to don't make sense since MSetPostList
     // returns documents in MSet order rather than docid order like other
