@@ -60,14 +60,14 @@ PhrasePostList::test_doc()
     LOGCALL(MATCH, bool, "PhrasePostList::test_doc", NO_ARGS);
 
     start_position_list(0);
-    poslists[0]->next();
-    if (poslists[0]->at_end()) RETURN(false);
+    if (!poslists[0]->next())
+	RETURN(false);
 
     unsigned read_hwm = 0;
+    Xapian::termpos b;
     do {
 	Xapian::termpos base = poslists[0]->get_position();
 	Xapian::termpos pos = base;
-	Xapian::termpos b;
 	unsigned i = 0;
 	do {
 	    if (++i == terms.size()) RETURN(true);
@@ -75,15 +75,14 @@ PhrasePostList::test_doc()
 		read_hwm = i;
 		start_position_list(i);
 	    }
-	    poslists[i]->skip_to(pos + 1);
-	    if (poslists[i]->at_end()) RETURN(false);
+	    if (!poslists[i]->skip_to(pos + 1))
+		RETURN(false);
 	    pos = poslists[i]->get_position();
 	    b = pos + (terms.size() - i);
 	} while (b - base <= window);
 	// Advance the start of the window to the first position it could match
 	// in given the current position of term i.
-	poslists[0]->skip_to(b - window);
-    } while (!poslists[0]->at_end());
+    } while (poslists[0]->skip_to(b - window));
     RETURN(false);
 }
 
