@@ -47,6 +47,9 @@ class RemoteSubMatch : public SubMatch {
      */
     bool decreasing_relevance;
 
+    /// uncollapsed_upper_bound from the remote MSet.
+    Xapian::doccount uncollapsed_upper_bound;
+
     /// The factor to use to convert weights to percentages.
     double percent_factor;
 
@@ -72,6 +75,11 @@ class RemoteSubMatch : public SubMatch {
     PostList * get_postlist(MultiMatch * matcher,
 			    Xapian::termcount * total_subqs_ptr);
 
+    /// Get uncollapsed_upper_bound from the remote MSet.
+    Xapian::doccount get_uncollapsed_upper_bound() const {
+	return uncollapsed_upper_bound;
+    }
+
     /// Get percentage factor - only valid after get_postlist().
     double get_percent_factor() const { return percent_factor; }
 
