@@ -1,7 +1,7 @@
 /** @file replicatetcpclient.cc
  *  @brief TCP/IP replication client class.
  */
-/* Copyright (C) 2008,2010,2015 Olly Betts
+/* Copyright (C) 2008,2010,2011,2015 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,11 +22,10 @@
 
 #include "replicatetcpclient.h"
 
-#include "replication.h"
+#include "api/replication.h"
 
 #include "socket_utils.h"
 #include "tcpclient.h"
-#include "utils.h"
 
 using namespace std;
 
@@ -73,5 +72,5 @@ ReplicateTcpClient::update_from_master(const std::string & path,
 
 ReplicateTcpClient::~ReplicateTcpClient()
 {
-    remconn.do_close(true);
+    remconn.shutdown();
 }
