@@ -1,7 +1,7 @@
 /* queryparser.cc: The non-lemon-generated parts of the QueryParser
  * class.
  *
- * Copyright (C) 2005,2006,2007,2008,2010 Olly Betts
+ * Copyright (C) 2005,2006,2007,2008,2010,2011,2012,2013,2015,2016 Olly Betts
  * Copyright (C) 2010 Adam Sjøgren
  *
  * This program is free software; you can redistribute it and/or
@@ -22,11 +22,13 @@
 
 #include <config.h>
 
+#include "xapian/error.h"
 #include <xapian/queryparser.h>
 #include <xapian/termiterator.h>
 
+#include "api/vectortermlist.h"
+#include "omassert.h"
 #include "queryparser_internal.h"
-#include "vectortermlist.h"
 
 #include <cstring>
 
@@ -54,8 +56,12 @@ SimpleStopper::get_description() const
     return desc;
 }
 
+RangeProcessor::~RangeProcessor() { }
+
 ValueRangeProcessor::~ValueRangeProcessor() { }
 
+FieldProcessor::~FieldProcessor() { }
+
 QueryParser::QueryParser(const QueryParser & o) : internal(o.internal) { }
 
 QueryParser &
@@ -65,6 +71,11 @@ QueryParser::operator=(const QueryParser & o)
     return *this;
 }
 
+QueryParser::QueryParser(QueryParser &&) = default;
+
+QueryParser &
+QueryParser::operator=(QueryParser &&) = default;
+
 QueryParser::QueryParser() : internal(new QueryParser::Internal) { }
 
 QueryParser::~QueryParser() { }
@@ -90,6 +101,33 @@ QueryParser::set_stopper(const Stopper * stopper)
 void
 QueryParser::set_default_op(Query::op default_op)
 {
+    switch (default_op) {
+	case Query::OP_AND:
+	case Query::OP_OR:
+	case Query::OP_NEAR:
+	case Query::OP_PHRASE:
+	case Query::OP_ELITE_SET:
+	case Query::OP_SYNONYM:
+	case Query::OP_MAX:
+	    // These are OK.
+	    break;
+	default:
+	    throw Xapian::InvalidArgumentError(
+		    "QueryParser::set_default_op() only accepts "
+		    "OP_AND"
+		    ", "
+		    "OP_OR"
+		    ", "
+		    "OP_NEAR"
+		    ", "
+		    "OP_PHRASE"
+		    ", "
+		    "OP_ELITE_SET"
+		    ", "
+		    "OP_SYNONYM"
+		    " or "
+		    "OP_MAX");
+    }
     internal->default_op = default_op;
 }
 
@@ -105,9 +143,18 @@ QueryParser::set_database(const Database &db) {
 }
 
 void
-QueryParser::set_max_wildcard_expansion(Xapian::termcount max)
+QueryParser::set_max_expansion(Xapian::termcount max_expansion,
+			       int max_type,
+			       unsigned flags)
 {
-    internal->max_wildcard_expansion = max;
+    if (flags & FLAG_WILDCARD) {
+	internal->max_wildcard_expansion = max_expansion;
+	internal->max_wildcard_type = max_type;
+    }
+    if (flags & FLAG_PARTIAL) {
+	internal->max_partial_expansion = max_expansion;
+	internal->max_partial_type = max_type;
+    }
 }
 
 Query
@@ -134,26 +181,31 @@ void
 QueryParser::add_prefix(const string &field, const string &prefix)
 {
     Assert(internal.get());
-    internal->add_prefix(field, prefix, NON_BOOLEAN);
+    internal->add_prefix(field, prefix);
+}
+
+void
+QueryParser::add_prefix(const string &field, Xapian::FieldProcessor * proc)
+{
+    Assert(internal.get());
+    internal->add_prefix(field, proc);
 }
 
 void
 QueryParser::add_boolean_prefix(const string &field, const string &prefix,
-				bool exclusive)
+				const string* grouping)
 {
     Assert(internal.get());
-    // Don't allow the empty prefix to be set as boolean as it doesn't
-    // really make sense.
-    if (field.empty())
-	throw Xapian::UnimplementedError("Can't set the empty prefix to be a boolean filter");
-    filter_type type = (exclusive ? BOOLEAN_EXCLUSIVE : BOOLEAN);
-    internal->add_prefix(field, prefix, type);
+    internal->add_boolean_prefix(field, prefix, grouping);
 }
 
 void
-QueryParser::add_boolean_prefix(const string &field, const string &prefix)
+QueryParser::add_boolean_prefix(const string &field,
+				Xapian::FieldProcessor * proc,
+				const string* grouping)
 {
-    add_boolean_prefix(field, prefix, true);
+    Assert(internal.get());
+    internal->add_boolean_prefix(field, proc, grouping);
 }
 
 TermIterator
@@ -179,10 +231,11 @@ QueryParser::unstem_begin(const string &term) const
 }
 
 void
-QueryParser::add_valuerangeprocessor(Xapian::ValueRangeProcessor * vrproc)
+QueryParser::add_rangeprocessor(Xapian::RangeProcessor * range_proc,
+				const std::string* grouping)
 {
     Assert(internal.get());
-    internal->valrangeprocs.push_back(vrproc);
+    internal->rangeprocs.push_back(RangeProc(range_proc, grouping));
 }
 
 string
