@@ -31,7 +31,6 @@
 
 #define XAPIAN_DEPRECATED(X) X
 #include <xapian.h>
-#include "backendmanager_local.h"
 #include "testsuite.h"
 #include "testutils.h"
 
@@ -575,38 +574,31 @@ DEFINE_TESTCASE(topercent1, backend) {
 
 // tests the percentage values returned
 DEFINE_TESTCASE(topercent2, backend) {
-    BackendManagerLocal local_manager;
-    local_manager.set_datadir(test_driver::get_srcdir() + "/testdata/");
-    Xapian::Enquire localenq(local_manager.get_database("apitest_simpledata"));
     Xapian::Enquire enquire(get_database("apitest_simpledata"));
 
     int pct;
 
     // First, test a search in which the top document scores 100%.
     enquire.set_query(query("this"));
-    localenq.set_query(query("this"));
     Xapian::MSet mymset = enquire.get_mset(0, 20);
-    Xapian::MSet localmset = localenq.get_mset(0, 20);
 
     Xapian::MSetIterator i = mymset.begin();
     TEST(i != mymset.end());
     pct = mymset.convert_to_percent(i);
     TEST_EQUAL(pct, 100);
 
-    TEST_EQUAL(mymset.get_matches_lower_bound(), localmset.get_matches_lower_bound());
-    TEST_EQUAL(mymset.get_matches_upper_bound(), localmset.get_matches_upper_bound());
-    TEST_EQUAL(mymset.get_matches_estimated(), localmset.get_matches_estimated());
-    TEST_EQUAL_DOUBLE(mymset.get_max_attained(), localmset.get_max_attained());
-    TEST_EQUAL(mymset.size(), localmset.size());
-    TEST(mset_range_is_same(mymset, 0, localmset, 0, mymset.size()));
+    TEST_EQUAL(mymset.get_matches_lower_bound(), 6);
+    TEST_EQUAL(mymset.get_matches_upper_bound(), 6);
+    TEST_EQUAL(mymset.get_matches_estimated(), 6);
+    TEST_EQUAL_DOUBLE(mymset.get_max_attained(), 0.0553904060041786);
+    TEST_EQUAL(mymset.size(), 6);
+    mset_expect_order(mymset, 2, 1, 3, 5, 6, 4);
 
     // A search in which the top document doesn't have 100%
     Xapian::Query q = query(Xapian::Query::OP_OR,
 			    "this", "line", "paragraph", "rubbish");
     enquire.set_query(q);
-    localenq.set_query(q);
     mymset = enquire.get_mset(0, 20);
-    localmset = localenq.get_mset(0, 20);
 
     i = mymset.begin();
     TEST(i != mymset.end());
@@ -621,12 +613,12 @@ DEFINE_TESTCASE(topercent2, backend) {
     TEST_REL(pct,>,40);
     TEST_REL(pct,<,50);
 
-    TEST_EQUAL(mymset.get_matches_lower_bound(), localmset.get_matches_lower_bound());
-    TEST_EQUAL(mymset.get_matches_upper_bound(), localmset.get_matches_upper_bound());
-    TEST_EQUAL(mymset.get_matches_estimated(), localmset.get_matches_estimated());
-    TEST_EQUAL_DOUBLE(mymset.get_max_attained(), localmset.get_max_attained());
-    TEST_EQUAL(mymset.size(), localmset.size());
-    TEST(mset_range_is_same(mymset, 0, localmset, 0, mymset.size()));
+    TEST_EQUAL(mymset.get_matches_lower_bound(), 6);
+    TEST_EQUAL(mymset.get_matches_upper_bound(), 6);
+    TEST_EQUAL(mymset.get_matches_estimated(), 6);
+    TEST_EQUAL_DOUBLE(mymset.get_max_attained(), 1.67412192414056);
+    TEST_EQUAL(mymset.size(), 6);
+    mset_expect_order(mymset, 3, 1, 4, 2, 5, 6);
 
     return true;
 }
@@ -834,8 +826,9 @@ DEFINE_TESTCASE(pctcutoff2, backend) {
 
     Xapian::MSet mset2 = enquire.get_mset(0, 1);
     TEST_EQUAL(mset2.size(), 1);
-    TEST_EQUAL(mset2.get_matches_lower_bound(), 1);
-    TEST_REL(mset2.get_uncollapsed_matches_lower_bound(),>=,1);
+    TEST_REL(mset2.get_matches_lower_bound(),>=,1);
+    TEST_REL(mset2.get_uncollapsed_matches_lower_bound(),>=,
+	     mset2.get_matches_lower_bound());
     TEST_REL(mset2.get_uncollapsed_matches_lower_bound(),<=,mset.size());
     TEST_REL(mset2.get_uncollapsed_matches_upper_bound(),>=,mset.size());
     TEST_REL(mset2.get_uncollapsed_matches_lower_bound(),<=,mset2.get_uncollapsed_matches_estimated());
@@ -1290,6 +1283,9 @@ DEFINE_TESTCASE(rsetmultidb3, backend && !multi) {
 
 /// Simple test of the elite set operator.
 DEFINE_TESTCASE(eliteset1, backend) {
+    XFAIL_FOR_BACKEND("multi_remoteprog_glass",
+		      "Multi remote databases are currently buggy");
+
     Xapian::Database mydb(get_database("apitest_simpledata"));
     Xapian::Enquire enquire(mydb);
 
@@ -1311,6 +1307,9 @@ DEFINE_TESTCASE(eliteset1, backend) {
 /// Test that the elite set operator works if the set contains
 /// sub-expressions (regression test)
 DEFINE_TESTCASE(eliteset2, backend) {
+    XFAIL_FOR_BACKEND("multi_remoteprog_glass",
+		      "Multi remote databases are currently buggy");
+
     Xapian::Database mydb(get_database("apitest_simpledata"));
     Xapian::Enquire enquire(mydb);
 
@@ -1386,6 +1385,12 @@ DEFINE_TESTCASE(eliteset3, backend) {
 
 /// Test that elite set doesn't pick terms with 0 frequency
 DEFINE_TESTCASE(eliteset4, backend) {
+    XFAIL_FOR_BACKEND("multi_glass_remoteprog_glass",
+		      "Multi remote databases are currently buggy");
+
+    XFAIL_FOR_BACKEND("multi_remoteprog_glass",
+		      "Multi remote databases are currently buggy");
+
     Xapian::Database mydb1(get_database("apitest_simpledata"));
     Xapian::Enquire enquire1(mydb1);
 
@@ -1486,8 +1491,13 @@ DEFINE_TESTCASE(termlisttermfreq1, backend) {
     return true;
 }
 
-/// Test the termfrequency and termweight info returned for query terms
+/// Test the termfreq and termweight info returned for query terms
 DEFINE_TESTCASE(qterminfo1, backend) {
+    XFAIL_FOR_BACKEND("multi_glass_remoteprog_glass",
+		      "Multi remote databases are currently buggy");
+
+    XFAIL_FOR_BACKEND("multi_remoteprog_glass",
+		      "Multi remote databases are currently buggy");
     Xapian::Database mydb1(get_database("apitest_simpledata", "apitest_simpledata2"));
     Xapian::Enquire enquire1(mydb1);
 
@@ -1543,6 +1553,9 @@ DEFINE_TESTCASE(qterminfo1, backend) {
 
 /// Regression test for bug #37.
 DEFINE_TESTCASE(qterminfo2, backend) {
+    XFAIL_FOR_BACKEND("multi_remoteprog_glass",
+		      "Multi remote databases are currently buggy");
+
     Xapian::Database db(get_database("apitest_simpledata"));
     Xapian::Enquire enquire(db);
 
@@ -1586,6 +1599,12 @@ DEFINE_TESTCASE(msetzeroitems1, backend) {
 
 // test that the matches_* of a simple query are as expected
 DEFINE_TESTCASE(matches1, backend) {
+    XFAIL_FOR_BACKEND("multi_glass_remoteprog_glass",
+		      "Multi remote databases are currently buggy");
+
+    XFAIL_FOR_BACKEND("multi_remoteprog_glass",
+		      "Multi remote databases are currently buggy");
+
     Xapian::Enquire enquire(get_database("apitest_simpledata"));
     Xapian::Query myquery;
     Xapian::MSet mymset;
