@@ -384,14 +384,36 @@ DEFINE_TESTCASE(testlock1, chert || glass) {
     return true;
 }
 
-/// Test that locked() returns false for backends which don't support update.
-/// Regression test for bug fixed in 1.4.6.
-DEFINE_TESTCASE(testlock2, backend && !writable && !multi) {
+/** Test that locked() returns false for databases which don't support update.
+ *
+ *  Regression test for bug fixed in 1.4.6.
+ *
+ *  The remote backend doesn't support locked() currently.
+ *
+ *  An inmemory Database is always actually a WritableDatabase viewed as a
+ *  Database, so it should always report being locked for writing - this is
+ *  tested by testlock3 below.
+ */
+DEFINE_TESTCASE(testlock2, backend && !remote && !inmemory) {
     Xapian::Database db = get_database("apitest_simpledata");
     TEST(!db.locked());
     return true;
 }
 
+/** Test that locked() returns true for inmemory Database objects.
+ *
+ *  An inmemory Database is always actually a WritableDatabase viewed as a
+ *  Database, so it should always report being locked for writing.
+ *
+ *  Regression test for bug fixed in 1.4.14 - earlier versions always returned
+ *  false for an inmemory Database here.
+ */
+DEFINE_TESTCASE(testlock3, inmemory) {
+    Xapian::Database db = get_database("apitest_simpledata");
+    TEST(db.locked());
+    return true;
+}
+
 class CheckMatchDecider : public Xapian::MatchDecider {
     mutable bool called;
 
