@@ -25,20 +25,26 @@
 
 #include <xapian.h>
 
+#include "safeunistd.h"
+
 #include "apitest.h"
 #include "testutils.h"
 
 using namespace std;
 
 #define COUNT_CLOSEDEXC(CODE) \
-    try { CODE; } catch (const Xapian::DatabaseError &) { ++closedexc_count; }
+    try { \
+	CODE; \
+    } catch (const Xapian::DatabaseClosedError &) { \
+	++closedexc_count; \
+    }
 
 #define IF_NOT_CLOSEDEXC(CODE) \
     do { \
 	hadexc = false; \
 	try { \
 	    CODE; \
-	} catch (const Xapian::DatabaseError &) { \
+	} catch (const Xapian::DatabaseClosedError &) { \
 	    ++closedexc_count; \
 	    hadexc = true; \
 	} \
@@ -139,7 +145,7 @@ struct closedb1_iterators {
 	try {
 	    ++pl1;
 	    advanced = true;
-	} catch (const Xapian::DatabaseError &) {}
+	} catch (const Xapian::DatabaseClosedError &) {}
 
 	if (advanced) {
 	    COUNT_CLOSEDEXC(TEST_EQUAL(*pl1, 2));
@@ -151,7 +157,7 @@ struct closedb1_iterators {
 	try {
 	    ++pl2;
 	    advanced = true;
-	} catch (const Xapian::DatabaseError &) {}
+	} catch (const Xapian::DatabaseClosedError &) {}
 
 	if (advanced) {
 	    COUNT_CLOSEDEXC(TEST_EQUAL(*pl2, 3));
@@ -163,7 +169,7 @@ struct closedb1_iterators {
 	try {
 	    ++tl1;
 	    advanced = true;
-	} catch (const Xapian::DatabaseError &) {}
+	} catch (const Xapian::DatabaseClosedError &) {}
 
 	if (advanced) {
 	    COUNT_CLOSEDEXC(TEST_EQUAL(*tl1, "api"));
@@ -175,7 +181,7 @@ struct closedb1_iterators {
 	try {
 	    ++atl1;
 	    advanced = true;
-	} catch (const Xapian::DatabaseError &) {}
+	} catch (const Xapian::DatabaseClosedError &) {}
 
 	if (advanced) {
 	    COUNT_CLOSEDEXC(TEST_EQUAL(*atl1, "that"));
@@ -186,7 +192,7 @@ struct closedb1_iterators {
 	try {
 	    ++pil1;
 	    advanced = true;
-	} catch (const Xapian::DatabaseError &) {}
+	} catch (const Xapian::DatabaseClosedError &) {}
 
 	if (advanced) {
 	    COUNT_CLOSEDEXC(TEST_EQUAL(*pil1, 28));
@@ -212,8 +218,16 @@ DEFINE_TESTCASE(closedb1, backend) {
     // Close the database.
     db.close();
 
-    // Reopening a closed database should always raise DatabaseError.
-    TEST_EXCEPTION(Xapian::DatabaseError, db.reopen());
+    // Dup stdout to the fds which the database was using, to try to catch
+    // issues with lingering references to closed fds (regression test for
+    // early development versions of honey).
+    vector<int> fds;
+    for (int i = 0; i != 6; ++i) {
+	fds.push_back(dup(1));
+    }
+
+    // Reopening a closed database should always raise DatabaseClosedError.
+    TEST_EXCEPTION(Xapian::DatabaseClosedError, db.reopen());
 
     // Run the test again, checking that we get some "closed" exceptions.
     closedexc_count = iters.perform();
@@ -227,18 +241,22 @@ DEFINE_TESTCASE(closedb1, backend) {
     // Calling close repeatedly is okay.
     db.close();
 
+    for (int fd : fds) {
+	close(fd);
+    }
     return true;
 }
 
 // Test closing a writable database, and that it drops the lock.
-DEFINE_TESTCASE(closedb2, writable && !inmemory && !remote) {
+DEFINE_TESTCASE(closedb2, writable && path) {
     Xapian::WritableDatabase dbw1(get_named_writable_database("apitest_closedb2"));
     TEST_EXCEPTION(Xapian::DatabaseLockError,
 		   Xapian::WritableDatabase db(get_named_writable_database_path("apitest_closedb2"),
 					       Xapian::DB_OPEN));
     dbw1.close();
     Xapian::WritableDatabase dbw2 = get_named_writable_database("apitest_closedb2");
-    TEST_EXCEPTION(Xapian::DatabaseError, dbw1.postlist_begin("paragraph"));
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
+	       dbw1.postlist_begin("paragraph"));
     TEST_EQUAL(dbw2.postlist_begin("paragraph"), dbw2.postlist_end("paragraph"));
 
     return true;
@@ -251,36 +269,36 @@ DEFINE_TESTCASE(closedb3, backend) {
     db.close();
     try {
 	TEST_EQUAL(db.get_uuid(), uuid);
-    } catch (const Xapian::DatabaseError &) {
+    } catch (const Xapian::DatabaseClosedError &) {
     }
     try {
 	TEST(db.has_positions());
-    } catch (const Xapian::DatabaseError &) {
+    } catch (const Xapian::DatabaseClosedError &) {
     }
     try {
 	TEST_EQUAL(db.get_doccount(), 566);
-    } catch (const Xapian::DatabaseError &) {
+    } catch (const Xapian::DatabaseClosedError &) {
     }
     try {
 	TEST_EQUAL(db.get_lastdocid(), 566);
-    } catch (const Xapian::DatabaseError &) {
+    } catch (const Xapian::DatabaseClosedError &) {
     }
     try {
 	TEST_REL(db.get_doclength_lower_bound(), <, db.get_avlength());
-    } catch (const Xapian::DatabaseError &) {
+    } catch (const Xapian::DatabaseClosedError &) {
     }
     try {
 	TEST_REL(db.get_doclength_upper_bound(), >, db.get_avlength());
-    } catch (const Xapian::DatabaseError &) {
+    } catch (const Xapian::DatabaseClosedError &) {
     }
     try {
 	TEST(db.get_wdf_upper_bound("king"));
-    } catch (const Xapian::DatabaseError &) {
+    } catch (const Xapian::DatabaseClosedError &) {
     }
     try {
 	// For non-remote databases, keep_alive() is a no-op anyway.
 	db.keep_alive();
-    } catch (const Xapian::DatabaseError &) {
+    } catch (const Xapian::DatabaseClosedError &) {
     }
     return true;
 }
@@ -328,21 +346,21 @@ DEFINE_TESTCASE(closedb5, transactions) {
 	TEST_EXCEPTION(Xapian::InvalidOperationError,
 		       wdb.commit_transaction());
 
-	// begin_transaction() is no-op or throws DatabaseError. We may be
+	// begin_transaction() is no-op or throws DatabaseClosedError. We may be
 	// able to call db.begin_transaction(), but we can't make any changes
 	// inside that transaction. If begin_transaction() succeeds, then
 	// commit_transaction() either end the transaction or throw
-	// DatabaseError.
+	// DatabaseClosedError.
 	bool advanced = false;
 	try {
 	    wdb.begin_transaction();
 	    advanced = true;
-	} catch (const Xapian::DatabaseError &) {
+	} catch (const Xapian::DatabaseClosedError &) {
 	}
 	if (advanced) {
 	    try {
 		wdb.commit_transaction();
-	    } catch (const Xapian::DatabaseError &) {
+	    } catch (const Xapian::DatabaseClosedError &) {
 	    }
 	}
     }
@@ -358,12 +376,12 @@ DEFINE_TESTCASE(closedb5, transactions) {
 	try {
 	    wdb.begin_transaction();
 	    advanced = true;
-	} catch (const Xapian::DatabaseError &) {
+	} catch (const Xapian::DatabaseClosedError &) {
 	}
 	if (advanced) {
 	    try {
 		wdb.cancel_transaction();
-	    } catch (const Xapian::DatabaseError &) {
+	    } catch (const Xapian::DatabaseClosedError &) {
 	    }
 	}
     }
@@ -379,7 +397,7 @@ DEFINE_TESTCASE(closedb6, remote) {
     try {
 	db.keep_alive();
 	return false;
-    } catch (const Xapian::DatabaseError &) {
+    } catch (const Xapian::DatabaseClosedError &) {
     }
     return true;
 }
@@ -394,18 +412,18 @@ DEFINE_TESTCASE(closedb7, writable) {
     // db.commit() is a no-op, and so doesn't have to fail.
     try {
 	db.commit();
-    } catch (const Xapian::DatabaseError &) {
+    } catch (const Xapian::DatabaseClosedError &) {
     }
 
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.add_document(Xapian::Document()));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.delete_document(1));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.replace_document(1, Xapian::Document()));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.replace_document(2, Xapian::Document()));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.replace_document("Qi", Xapian::Document()));
 
     return true;
@@ -418,13 +436,13 @@ DEFINE_TESTCASE(closedb8, writable && spelling) {
     db.add_spelling("pneumonia");
     db.close();
 
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.add_spelling("penmanship"));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.remove_spelling("pneumatic"));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.get_spelling_suggestion("newmonia"));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.spellings_begin());
 
     return true;
@@ -437,15 +455,15 @@ DEFINE_TESTCASE(closedb9, writable && synonyms) {
     db.add_synonym("honor", "honour");
     db.close();
 
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.add_synonym("behavior", "behaviour"));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.remove_synonym("honor", "honour"));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.clear_synonyms("honor"));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.synonyms_begin("color"));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.synonym_keys_begin());
 
     return true;
@@ -458,13 +476,13 @@ DEFINE_TESTCASE(closedb10, writable && metadata) {
     db.set_metadata("bar", "BAR");
     db.close();
 
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.set_metadata("test", "TEST"));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.get_metadata("foo"));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.get_metadata("bar"));
-    TEST_EXCEPTION(Xapian::DatabaseError,
+    TEST_EXCEPTION(Xapian::DatabaseClosedError,
 		   db.metadata_keys_begin());
 
     return true;
