@@ -1,7 +1,7 @@
 /* api_valuestats.cc: tests of the value statistics functions.
  *
  * Copyright 2008 Lemur Consulting Ltd
- * Copyright 2008,2009,2011 Olly Betts
+ * Copyright 2008,2009,2011,2017 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -72,13 +72,19 @@ DEFINE_TESTCASE(valuestats1, writable && valuestats) {
     TEST_EQUAL(db_w.get_value_lower_bound(1), "cheese");
     TEST_EQUAL(db_w.get_value_upper_bound(1), "cheese");
 
-    // Deleting a document affects the count, but not the bounds.
+    // Deleting a document affects the count, but probably not the bounds.
+    // It may with a multi-database, if the document which was deleted
+    // was the only one in that shard.
     db_w.delete_document(1);
     TEST_EQUAL(db_w.get_value_freq(1), 1);
     TEST_EQUAL(db_w.get_value_lower_bound(1), "cheese");
     TEST_EQUAL(db_w.get_value_upper_bound(1), "cheese");
     TEST_EQUAL(db_w.get_value_freq(0), 1);
-    TEST_EQUAL(db_w.get_value_lower_bound(0), "hello");
+    if (!startswith(get_dbtype(), "multi")) {
+	TEST_EQUAL(db_w.get_value_lower_bound(0), "hello");
+    } else {
+	TEST_EQUAL(db_w.get_value_lower_bound(0), "world");
+    }
     TEST_EQUAL(db_w.get_value_upper_bound(0), "world");
 
     // Deleting all the documents returns the bounds to their original value.
