@@ -1933,7 +1933,7 @@ DEFINE_TESTCASE(lazytablebug1, chert || glass) {
  *  Chert also has the same duff code but this testcase doesn't actually
  *  tickle the bug there.
  */
-DEFINE_TESTCASE(cursordelbug1, chert || glass) {
+DEFINE_TESTCASE(cursordelbug1, writable && path) {
     static const int terms[] = { 219, 221, 222, 223, 224, 225, 226 };
     static const int copies[] = { 74, 116, 199, 21, 45, 155, 189 };
 
@@ -2097,3 +2097,28 @@ DEFINE_TESTCASE(modifyvalues1, writable) {
 
     return true;
 }
+
+/** Regression test for protocol design bug.
+ *
+ *  Previously some messages didn't send a reply but could result in an
+ *  exception being sent over the link.  That exception would then get
+ *  read as a response to the next message instead of its actual response
+ *  so we'd be out of step.
+ *
+ *  This also affected MSG_DELETEDOCUMENTTERM, MSG_CANCEL, MSG_SETMETADATA
+ *  and MSG_ADDSPELLING but it's harder to reliably trigger an exception
+ *  from any of those.
+ *
+ *  See #783.  Fixed in 1.4.12.
+ */
+DEFINE_TESTCASE(protocolbug1, remote && writable) {
+    Xapian::WritableDatabase db = get_writable_database("");
+    Xapian::Document doc;
+    doc.add_term(string(300, 'x'));
+
+    TEST_EXCEPTION(Xapian::InvalidArgumentError,
+		   db.replace_document(1, doc));
+    db.commit();
+
+    return true;
+}
