@@ -1,7 +1,7 @@
 /** @file apitest.h
  * @brief test functionality of the Xapian API
  */
-/* Copyright (C) 2007,2009,2011 Olly Betts
+/* Copyright (C) 2007,2009,2011,2018 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,8 @@ Xapian::WritableDatabase get_named_writable_database(const std::string &name, co
 
 std::string get_named_writable_database_path(const std::string &name);
 
+std::string get_compaction_output_path(const std::string& name);
+
 Xapian::Database get_remote_database(const std::string &db, unsigned timeout);
 
 Xapian::Database get_writable_database_as_database();
@@ -72,4 +74,7 @@ void skip_test_for_backend(const std::string & backend_prefix);
 #define SKIP_TEST_UNLESS_BACKEND(B) skip_test_unless_backend(B)
 #define SKIP_TEST_FOR_BACKEND(B) skip_test_for_backend(B)
 
+void XFAIL_FOR_BACKEND(const std::string& backend_prefix,
+		       const char* msg);
+
 #endif // XAPIAN_INCLUDED_APITEST_H
