@@ -2,7 +2,7 @@
  * @brief Base class for backend handling in test harness
  */
 /* Copyright 1999,2000,2001 BrightStation PLC
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2017 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2017,2018 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -43,11 +43,11 @@ class BackendManager {
     /// The current data directory
     std::string datadir;
 
+  protected:
     /// Index data from zero or more text files into a database.
     void index_files_to_database(Xapian::WritableDatabase & database,
 				 const std::vector<std::string> & files);
 
-  protected:
     bool create_dir_if_needed(const std::string &dirname);
 
     /** Virtual method implementing get_database().
@@ -66,40 +66,11 @@ class BackendManager {
      */
     virtual std::string do_get_database_path(const std::vector<std::string> &files);
 
-#ifdef XAPIAN_HAS_INMEMORY_BACKEND
-    /// Get a writable inmemory database instance.
-    Xapian::WritableDatabase getwritedb_inmemory(const std::vector<std::string> &files);
-#endif
-
-#ifdef XAPIAN_HAS_CHERT_BACKEND
-  protected:
-    std::string createdb_chert(const std::vector<std::string> &files);
-
   public:
-    /// Get a writable chert database instance.
-    Xapian::WritableDatabase getwritedb_chert(const std::string & name,
-					      const std::vector<std::string> &files);
-
-    /// Get the path of a writable chert database instance.
-    std::string getwritedb_chert_path(const std::string & name);
-#endif
-
-#ifdef XAPIAN_HAS_GLASS_BACKEND
-  protected:
-    std::string createdb_glass(const std::vector<std::string> &files);
-
-  public:
-    /// Get a writable glass database instance.
-    Xapian::WritableDatabase getwritedb_glass(const std::string & name,
-					      const std::vector<std::string> &files);
-
-    /// Get the path of a writable glass database instance.
-    std::string getwritedb_glass_path(const std::string & name);
-#endif
-
-  public:
-    /// Constructor - set up default state.
-    BackendManager() { }
+    /// Constructor.
+    explicit
+    BackendManager(const std::string& datadir_)
+	: datadir(datadir_) {}
 
     /** We have virtual methods and want to be able to delete derived classes
      *  using a pointer to the base class, so we need a virtual destructor.
@@ -110,10 +81,6 @@ class BackendManager {
      */
     virtual std::string get_dbtype() const;
 
-    /** Set the directory to store data in.
-     */
-    void set_datadir(const std::string &datadir_) { datadir = datadir_; }
-
     /** Get the directory to store data in.
      */
     const std::string & get_datadir() const { return datadir; }
@@ -138,6 +105,9 @@ class BackendManager {
 					      const std::string &),
 				  const std::string &arg);
 
+    /// Get a database instance by path
+    virtual Xapian::Database get_database_by_path(const std::string& path);
+
     /// Get the path of a database instance, if such a thing exists.
     std::string get_database_path(const std::vector<std::string> &files);
 
@@ -153,18 +123,44 @@ class BackendManager {
     /// Get a writable database instance.
     virtual Xapian::WritableDatabase get_writable_database(const std::string & name, const std::string & file);
 
+    /// Get a remote Xapian::WritableDatabase instance with specified args.
+    virtual Xapian::WritableDatabase
+    get_remote_writable_database(std::string args);
+
     /// Get the path of a writable database instance, if such a thing exists.
     virtual std::string get_writable_database_path(const std::string & name);
 
+    /// Get a generated writable database instance
+    virtual Xapian::WritableDatabase
+    get_generated_database(const std::string& name);
+
+    /// Get the path to use for generating a database, if supported.
+    virtual std::string get_generated_database_path(const std::string & name);
+
+    /// Finalise the generated database
+    virtual void finalise_generated_database(const std::string& name);
+
     /// Get a remote database instance with the specified timeout.
     virtual Xapian::Database get_remote_database(const std::vector<std::string> & files, unsigned int timeout);
 
+    /** Get the args for opening a writable remote database with the
+     *  specified timeout.
+     */
+    virtual std::string get_writable_database_args(const std::string& path,
+						   unsigned int timeout);
+
     /// Create a Database object for the last opened WritableDatabase.
     virtual Xapian::Database get_writable_database_as_database();
 
     /// Create a WritableDatabase object for the last opened WritableDatabase.
     virtual Xapian::WritableDatabase get_writable_database_again();
 
+    /// Get the path of the last opened WritableDatabase.
+    virtual std::string get_writable_database_path_again();
+
+    /// Get a path to compact a database to.
+    virtual std::string get_compaction_output_path(const std::string& name);
+
     /** Called after each test, to perform any necessary cleanup.
      *
      *  May be called more than once for a given test in some cases.
