@@ -1,7 +1,7 @@
 /** @file backendmanager_chert.h
  * @brief BackendManager subclass for chert databases.
  */
-/* Copyright (C) 2007,2008,2009 Olly Betts
+/* Copyright (C) 2007,2008,2009,2018 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -43,7 +43,7 @@ class BackendManagerChert : public BackendManager {
     std::string do_get_database_path(const std::vector<std::string> & files);
 
   public:
-    BackendManagerChert() { }
+    BackendManagerChert(const std::string& datadir_);
 
     /// Return a string representing the current database type.
     std::string get_dbtype() const;
@@ -55,11 +55,16 @@ class BackendManagerChert : public BackendManager {
     /// Get the path of Chert Xapian::WritableDatabase instance.
     std::string get_writable_database_path(const std::string & name);
 
-    /// Create a Database object for the last opened WritableDatabase.
-    Xapian::Database get_writable_database_as_database();
+    std::string get_compaction_output_path(const std::string& name);
+
+    /// Get the path to use for generating a database, if supported.
+    std::string get_generated_database_path(const std::string & name);
 
     /// Create a WritableDatabase object for the last opened WritableDatabase.
     Xapian::WritableDatabase get_writable_database_again();
+
+    /// Get the path of the last opened WritableDatabase.
+    std::string get_writable_database_path_again();
 };
 
 #endif // XAPIAN_INCLUDED_BACKENDMANAGER_CHERT_H
