@@ -1,7 +1,7 @@
 /** @file backendmanager_multi.h
  * @brief BackendManager subclass for multi databases.
  */
-/* Copyright (C) 2007,2009,2017,2019 Olly Betts
+/* Copyright (C) 2007,2009,2017,2018,2019 Olly Betts
  * Copyright (C) 2008 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
@@ -25,24 +25,26 @@
 #include "backendmanager.h"
 
 #include <string>
+#include <vector>
 
-#include <xapian/types.h>
-#include <xapian/postingiterator.h>
+#include <xapian/database.h>
 
 /// BackendManager subclass for multi databases.
 class BackendManagerMulti : public BackendManager {
-    /// The type to use for the sub-databases.
-    std::string subtype;
-
-    /// The path of the last writable database used.
-    std::string last_wdb_path;
-
     /// Don't allow assignment.
     void operator=(const BackendManagerMulti &);
 
     /// Don't allow copying.
     BackendManagerMulti(const BackendManagerMulti &);
 
+    /// The path of the last writable database used.
+    std::string last_wdb_path;
+
+    // vector of sub_managers.
+    std::vector<BackendManager*> sub_managers;
+
+    std::string cachedir;
+
     std::string createdb_multi(const std::string& name,
 			       const std::vector<std::string>& files);
 
@@ -51,7 +53,8 @@ class BackendManagerMulti : public BackendManager {
     std::string do_get_database_path(const std::vector<std::string> & files);
 
   public:
-    BackendManagerMulti(const std::string & subtype_);
+    BackendManagerMulti(const std::string& datadir_,
+			std::vector<BackendManager*> sub_manager_);
 
     /// Return a string representing the current database type.
     std::string get_dbtype() const;
@@ -62,13 +65,15 @@ class BackendManagerMulti : public BackendManager {
     /// Get the path of Xapian::WritableDatabase instance.
     std::string get_writable_database_path(const std::string & name);
 
-    /// Create a Database object for the last opened WritableDatabase.
-    Xapian::Database get_writable_database_as_database();
+    std::string get_compaction_output_path(const std::string& name);
 
     std::string get_generated_database_path(const std::string& name);
 
     /// Create a WritableDatabase object for the last opened WritableDatabase.
     Xapian::WritableDatabase get_writable_database_again();
+
+    /// Get the path of the last opened WritableDatabase.
+    std::string get_writable_database_path_again();
 };
 
 #endif // XAPIAN_INCLUDED_BACKENDMANAGER_MULTI_H
