@@ -45,8 +45,8 @@ class BackendManagerRemoteProg : public BackendManagerRemote {
     Xapian::Database do_get_database(const std::vector<std::string> & files);
 
   public:
-    BackendManagerRemoteProg(const std::string & remote_type_)
-	: BackendManagerRemote(remote_type_) { }
+    explicit BackendManagerRemoteProg(BackendManager* sub_manager_)
+	: BackendManagerRemote(sub_manager_) { }
 
     /// Return a string representing the current database type.
     std::string get_dbtype() const;
@@ -55,10 +55,17 @@ class BackendManagerRemoteProg : public BackendManagerRemote {
     Xapian::WritableDatabase get_writable_database(const std::string & name,
 						   const std::string & file);
 
+    /// Create a RemoteProg Xapian::WritableDatabase object with specified args.
+    Xapian::WritableDatabase
+    get_remote_writable_database(std::string args);
+
     /// Create a RemoteProg Xapian::Database with the specified timeout.
     Xapian::Database get_remote_database(const std::vector<std::string> & files,
 					 unsigned int timeout);
 
+    /// Get RemoteProg Xapian::Database instance of database at path
+    Xapian::Database get_database_by_path(const std::string& path);
+
     /// Create a Database object for the last opened WritableDatabase.
     Xapian::Database get_writable_database_as_database();
 
