@@ -1,6 +1,7 @@
-/* utf8itor.cc: iterate over a utf8 string.
- *
- * Copyright (C) 2006,2007,2010,2013,2015 Olly Betts
+/** @file utf8itor.cc
+ * @brief iterate over a utf8 string.
+ */
+/* Copyright (C) 2006,2007,2010,2013,2015,2019 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +26,9 @@
 
 using namespace std;
 
-static inline bool bad_cont(unsigned char ch) { return (ch & 0xc0) != 0x80; }
+static inline bool bad_cont(unsigned char ch) {
+    return static_cast<signed char>(ch) >= static_cast<signed char>(0xc0);
+}
 
 namespace Xapian {
 
@@ -33,7 +36,7 @@ namespace Unicode {
 
 // buf should be at least 4 bytes.
 unsigned
-nonascii_to_utf8(unsigned ch, char * buf)
+nonascii_to_utf8(unsigned ch, char* buf)
 {
     if (ch < 0x800) {
 	buf[0] = char(0xc0 | (ch >> 6));
@@ -61,7 +64,7 @@ nonascii_to_utf8(unsigned ch, char * buf)
 
 }
 
-Utf8Iterator::Utf8Iterator(const char *p_)
+Utf8Iterator::Utf8Iterator(const char* p_)
 {
     assign(p_, strlen(p_));
 }
