@@ -1,7 +1,7 @@
 /** @file tradweight.cc
  * @brief Xapian::TradWeight class - the "traditional" probabilistic formula
  */
-/* Copyright (C) 2009,2010,2015 Olly Betts
+/* Copyright (C) 2009,2010,2011,2012,2014,2015,2017 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -44,9 +44,15 @@ TradWeight::clone() const
 void
 TradWeight::init(double factor)
 {
+    if (factor == 0.0) {
+	// This object is for the term-independent contribution, and that's
+	// always zero for this scheme.
+	return;
+    }
+
     Xapian::doccount tf = get_termfreq();
 
-    Xapian::weight tw = 0;
+    double tw = 0;
     if (get_rset_size() != 0) {
 	Xapian::doccount reltermfreq = get_reltermfreq();
 
@@ -83,7 +89,7 @@ TradWeight::init(double factor)
     // weight or similar.
     //
     // Truncating to zero doesn't seem a great approach in practice as it
-    // means that some terms in the query can have no affect at all on the
+    // means that some terms in the query can have no effect at all on the
     // ranking, and that some results can have zero weight, both of which
     // are seem surprising.
     //
@@ -136,18 +142,19 @@ TradWeight::unserialise(const string & s) const
     const char *end = ptr + s.size();
     double k = unserialise_double(&ptr, end);
     if (rare(ptr != end))
-	throw Xapian::NetworkError("Extra data in TradWeight::unserialise()");
+	throw Xapian::SerialisationError("Extra data in TradWeight::unserialise()");
     return new TradWeight(k);
 }
 
-Xapian::weight
-TradWeight::get_sumpart(Xapian::termcount wdf, Xapian::termcount len) const
+double
+TradWeight::get_sumpart(Xapian::termcount wdf, Xapian::termcount len,
+			Xapian::termcount) const
 {
     double wdf_double = wdf;
     return termweight * (wdf_double / (len * len_factor + wdf_double));
 }
 
-Xapian::weight
+double
 TradWeight::get_maxpart() const
 {
     // FIXME: need to force non-zero wdf_max to stop percentages breaking...
@@ -156,13 +163,13 @@ TradWeight::get_maxpart() const
     return termweight * (wdf_max / (doclen_lb * len_factor + wdf_max));
 }
 
-Xapian::weight
-TradWeight::get_sumextra(Xapian::termcount) const
+double
+TradWeight::get_sumextra(Xapian::termcount, Xapian::termcount) const
 {
     return 0;
 }
 
-Xapian::weight
+double
 TradWeight::get_maxextra() const
 {
     return 0;
